pub struct CotSourceArgs {
pub use_git: bool,
pub cot_path: Option<PathBuf>,
}Fields
use_git: boolUse the latest cot version from git instead of a published crate
cot_path: Option<PathBuf>Use cot from the specified path instead of a published crate