pub struct MigrationMakeArgs {
pub path: Option<PathBuf>,
pub app_name: Option<String>,
pub output_dir: Option<PathBuf>,
}Fields
path: Option<PathBuf>Path to the crate directory to generate migrations for [default: current directory]
app_name: Option<String>Name of the app to use in the migration (default: crate name)
output_dir: Option<PathBuf>Directory to write the migrations to (default: migrations/ directory in the crate’s src/ directory)