pub struct MigrationNewArgs {
pub name: String,
pub path: Option<PathBuf>,
pub app_name: Option<String>,
}Fields
name: StringName of the migration
path: Option<PathBuf>Path to the crate directory to create the migration in [default: current directory]
app_name: Option<String>Name of the app to use in the migration (default: crate name)