Structs
- Generated
Migration - A migration generated by the CLI and before converting to a Rust source code and writing to a file.
- Migration
AsSource - A migration represented as a generated and ready to write Rust source code.
- Migration
Generator - Migration
Generator Options - Model
InSource - Source
File
Enums
- DynDependency
- A version of
cot::db::migrations::MigrationDependencythat can be created at runtime and is using codegen types. - DynOperation
- A version of
cot::db::migrations::Operationthat can be created at runtime and is using codegen types.