Module migration_generator

Module migration_generator 

Structs

GeneratedMigration
A migration generated by the CLI and before converting to a Rust source code and writing to a file.
MigrationAsSource
A migration represented as a generated and ready to write Rust source code.
MigrationGenerator
MigrationGeneratorOptions
ModelInSource
SourceFile

Enums

DynDependency
A version of cot::db::migrations::MigrationDependency that can be created at runtime and is using codegen types.
DynOperation
A version of cot::db::migrations::Operation that can be created at runtime and is using codegen types.

Functions

list_migrations
make_migrations